pub struct ConnectionBuffer { /* private fields */ }Implementations
Sourceimpl ConnectionBuffer
impl ConnectionBuffer
pub fn new() -> Self
pub fn with_capacity(capacity: usize) -> Self
pub fn extend(&mut self, data: &[u8])
pub fn slice(&self, start: usize, len: usize) -> Bytes
pub fn consume(&mut self, len: usize)
Sourcepub fn compact(&mut self)
pub fn compact(&mut self)
Compact the buffer to reduce memory usage when oversized. Uses split_off pattern to avoid to_vec() allocation per standards 18.1.
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn capacity(&self) -> usize
pub fn remaining(&self) -> usize
pub fn reserve(&mut self, additional: usize)
pub fn clear(&mut self)
pub fn get_write_buffer(&mut self, min_size: usize) -> &mut [u8] ⓘ
Sourcepub unsafe fn advance_write(&mut self, len: usize)
pub unsafe fn advance_write(&mut self, len: usize)
Advance the write position of the buffer.
Safety
The caller must ensure that len bytes have been written to the
spare capacity returned by spare_capacity_mut().